@@ -4,7 +4,7 @@ import os
 import time
 
 from requests import HTTPError
-
+from deprecated import deprecated
 from atlassian import utils
 from .errors import (
     ApiError,
@@ -506,8 +506,9 @@ class Confluence(AtlassianRestAPI):
 
         return response.get("results")
 
+    @deprecated(version="2.4.2", reason="Use get_all_restrictions_for_content()")
     def get_all_restictions_for_content(self, content_id):
-        """keep typo method"""
+        """Let's use the get_all_restrictions_for_content()"""
         log.warning("Please, be informed that is deprecated as typo naming")
         return self.get_all_restrictions_for_content(content_id=content_id)
 
@@ -821,7 +822,7 @@ class Confluence(AtlassianRestAPI):
         :type  page_id: ``str``
         :param name: The name of the attachment
         :type  name: ``str``
-        :param content: Contains the content which should be uplaoded
+        :param content: Contains the content which should be uploaded
         :type  content: ``binary``
         :param content_type: Specify the HTTP content type. The default is
         :type  content_type: ``str``
@@ -1736,6 +1737,28 @@ class Confluence(AtlassianRestAPI):
 
         return response.get("results")
 
+    def get_all_members(self, group_name="confluence-users", expand=None):
+        """
+        Get  collection of all users in the given group
+        :param group_name
+        :param expand: OPTIONAL: A comma separated list of properties to expand on the content. status
+        :return:
+        """
+        limit = 50
+        flag = True
+        step = 0
+        members = []
+        while flag:
+            values = self.get_group_members(group_name=group_name, start=len(members), limit=limit, expand=expand)
+            step += 1
+            if len(values) == 0:
+                flag = False
+            else:
+                members.extend(values)
+        if not members:
+            print("Did not get members from {} group, please check permissions or connectivity".format(group_name))
+        return members
+
     def get_space(self, space_key, expand="description.plain,homepage"):
         """
         Get information about a space through space key
@@ -1771,7 +1794,7 @@ class Confluence(AtlassianRestAPI):
     ):
         """
         Get space content.
-        You can specify which type of content want to recieve, or get all content types.
+        You can specify which type of content want to receive, or get all content types.
         Use expand to get specific content properties or page
         :param content_type:
         :param space_key: The unique space key name
